==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: hu\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Üzleti Kapcsolati Adatok"

, "Organisation / Unit"
: "Szervezet / Egység"

, "Business Address"
: "Üzleti cím"

, "Email"
: "Email"

, "Telephone Work"
: "Üzleti telefonszám"

, "Telephone Cellphone"
: "Mobil telefonszám"

, "Telephone Car"
: "Autó telefonszám"

, "Telephone Fax"
: "Faxszám"

, "Telephone Page"
: "Személyhívó telefonszám"

, "URL"
: "URL"

, "Role"
: "Szerep"

, "Room"
: "Szoba"

, "Assistant"
: "Aszisztens"

, "Assistant Telephone"
: "Aszisztens telefonszáma"

, "Private Contact Data"
: "Privát Kapcsolati Adatok"

, "Private Address"
: "Privát cím"

, "Email Home"
: "Otthoni email"

, "Telephone Home"
: "Otthoni telefonszám"

, "Telephone Cellphone Private"
: "Privát mobil telefonszám"

, "Telephone Fax Home"
: "Otthoni faxszám"

, "URL Home"
: "Otthoni URL"

, "Other Data"
: "Egyéb adatok"

, "Birthday"
: "Születésnap"

, "Job Title"
: "Beosztás"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listák"

]
, "Percent"
: ""

, "Description"
: "Leírás"

, "Members"
: ""

, "Type"
: "Típus"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "Címjegyzék"
 ,"Címjegyzékek"

]
, "Contact, Contacts"
: [
  "Kapcsolat"
 ,"Kapcsolatok"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Ország"

, "City"
: "Város"

, "Postalcode"
: "Irányítószám"

, "Region"
: "Régió"

, "Street"
: "Utca"

, "Street 2"
: "Utca 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Ország (privát)"

, "City (private)"
: "Város (privát)"

, "Postalcode (private)"
: "Irányítószám (privát)"

, "Region (private)"
: "Régió (privát)"

, "Street (private)"
: "Utca (privát)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (privát)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Leírás"

, "Last Name"
: "Vezeték név"

, "Display Name"
: "Kijelzett név"

, "Full Name"
: "Teljes név"

, "First Name"
: "Kereszt név"

, "Middle Name"
: "Középső név"

, "Title"
: "Előtag"

, "Suffix"
: "Utótag"

, "Company"
: "Cég"

, "Unit"
: "Egység"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Szerepkör"

, "Salutation"
: "Megszólítás"

, "syncBackendIds"
: ""

, "Car phone"
: "Autó telefon"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (privát)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privát)"

, "Phone (private)"
: "Telefon (privát)"

, "Pager"
: "Személyhívó"

, "Phone"
: "Telefon"

, "Timezone"
: "Időzóna"

, "Web"
: "Web"

, "URL (private)"
: "URL (privát)"

, "Label"
: ""

, "Lists"
: "Listák"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Kapcsolati információk"

, "Company Address"
: "Céges cím"

, "New Contact"
: "Új kapcsolat"

, "ID"
: ""

, "Name"
: "Név"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Kapcsolatok importálása"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privát"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Címkék"

, "List Roles"
: ""

, "Street (Company Address)"
: "Utca (Céges cím)"

, "Street 2 (Company Address)"
: "Utca 2 (Céges cím)"

, "City (Company Address)"
: "Város (Céges cím)"

, "Region (Company Address)"
: "Régió (Céges cím)"

, "Postal Code (Company Address)"
: "Irányítószám (Céges cím)"

, "Country (Company Address)"
: "Ország (Céges cím)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Utca (Privát cím)"

, "Street 2 (Private Address)"
: "Utca 2 (Privát cím)"

, "City (Private Address)"
: "Város (Privát cím)"

, "Region (Private Address)"
: "Régió (Privát cím)"

, "Postal Code (Private Address)"
: "Irányítószám (Privát cím)"

, "Country (Private Address)"
: "Ország (Privát cím)"

, "Company Communication"
: "Céges kapcsolatok"

, "Private Communication"
: "Privát kapcsolatok"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privát)"

, "Web (private)"
: "Web (privát)"

, "Contacts"
: "Kapcsolatok"

, "Addressbooks"
: "Címjegyzékek"

, "User Account"
: "Felhasználói fiók"

, "Quick Search"
: ""

, "Postal Code"
: "Irányítószám"

, "Last Modified Time"
: "Utolsó módosítás ideje"

, "Last Modified By"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Created By"
: "Készítette"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Leírás megadása"

, "{0} must be given"
: ""

, "Member of List"
: "Lista tagja"

, "Map"
: "Térkép"

, "Company address"
: "Céges cím"

, "Private address"
: "Privát cím"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Személyes információk"

, "Parse address"
: "Cím felbontása"

, "Print contact"
: ""

, "Paste address"
: "Cím beillesztése"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Token mód vége"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Összes kapcsolat"

, "Default Addressbook"
: "Alapértelmezett címjegyzék"

, "The default addressbook for new contacts"
: "Alapértelmezett címjegyzék az új kapcsolatoknak"

, "Default Favorite"
: "Alapértelmezett kedvenc"

, "The default favorite which is loaded on addressbook startup"
: "Alapértelmezett kedvenc ami a címjegyzék indításakor betöltődik"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Kapcsolat mezőinek duplikálási ellenőrzése"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Ezeket a mezőket ellenőrzi egy új kapcsolat felvételekor. Ha egy rekordt egyforma mező adatokkal megtalál, a duplikált kivételt eldobja."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kapcsolat megszólítás elérhető"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Lehetséges kapcsolat megszólítás- Kérlek jegyezd meg, hogy azok további értékek ütközhetnek más Címjegyzék rendszerekkel exportáláskor vagy szinkronizáláskor."

, "Mr"
: "Úr"

, "Ms"
: "Asszony"

, "Parsing rules for addresses"
: "Címek felbontási szabályai"

, "Path to a XML file with address parsing rules."
: "Címek felbontási szabályait tartalmazó XML fájl elérése"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Kapcsolat VCARD importja"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kapcsolatokat importálta ###USERFULLNAME### ekkor: ###CURRENTDATE###  ###CURRENTTIME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Német Outlook 2007 CSV"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Kapcsolat CSV importja Outlook címjegyzékből"

, "Contact CSV import from mac address book"
: "Kapcsolat CSV importja mac címjegyzékből"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Kapcsolatok importálása a Google címjegyzékből"

, "manage shared addressbooks"
: "megosztott címjegyzékek kezelése"

, "Create new shared addressbook folders"
: "Új megosztott címjegyzék mappa készítése"

, "manage shared addressbook favorites"
: "kedvenc megosztott címjegyzék kezelése"

, "Create or update shared addressbook favorites"
: "Kedvenc megosztott címjegyzék készítése vagy frissítése"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s személyes címjegyzéke"

, "All contacts I have read grants for"
: "Összes kapcsolat, amihez olvasási engedélyem van"

, "My company"
: "Saját cégem"

, "All coworkers in my company"
: "Minden alkalmazott a saját cégemnél"

, "My contacts"
: "Kapcsolataim"

, "All contacts in my Addressbooks"
: "Minden kapcsolat a saját Címjegyzékemben"

, "Last modified by me"
: "Utoljára módosítottam"

, "All contacts that I have last modified"
: "Minden kapcsolat amit utoljára én módosítottam"

, "Internal Contacts"
: "Belső kapcsolatok"

, "List"
: "Lista"

, "Addressbook"
: "Címjegyzék"

, "Contact"
: "Kapcsolat"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-hu-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Hungarian (http://www.transifex.com/tine20/tine20/language/hu/)\nLanguage: hu\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Térkép"

, "Preferred Address"
: ""

, "Personal Information"
: "Személyes információk"

, "Salutation"
: "Megszólítás"

, "Title"
: "Előtag"

, "Short Name"
: ""

, "First Name"
: "Kereszt név"

, "Middle Name"
: "Középső név"

, "Last Name"
: "Vezeték név"

, "Company"
: "Cég"

, "Unit"
: "Egység"

, "Display Name"
: "Kijelzett név"

, "Industry, Industries"
: [
  ""
 ,""

]
, "Job Title"
: "Beosztás"

, "Birthday (private)"
: ""

, "Contact Information"
: "Kapcsolati információk"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privát)"

, "Mobile (private)"
: "Mobil (privát)"

, "Fax (private)"
: "Fax (privát)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privát)"

, "Web"
: "Web"

, "Company Address"
: "Céges cím"

, "Street"
: "Utca"

, "Street 2"
: "Utca 2"

, "Region"
: "Régió"

, "Postal Code"
: "Irányítószám"

, "City"
: "Város"

, "Country"
: "Ország"

, "Private Address"
: "Privát cím"

, "Description"
: "Leírás"

, "Enter description"
: "Leírás megadása"

, "Groups"
: ""

, "Parse address"
: "Cím felbontása"

, "Print contact"
: ""

, "Paste address"
: "Cím beillesztése"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Token mód vége"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Kapcsolat"
 ,"Kapcsolatok"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "CardDAV URL"

, "New Contact"
: "Új kapcsolat"

, "Addressbook, Addressbooks"
: [
  "Címjegyzék"
 ,"Címjegyzékek"

]
, "ID"
: ""

, "Name"
: "Név"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Privát"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Utótag"

, "Birthday"
: "Születésnap"

, "Job Role"
: "Szerepkör"

, "Room"
: "Szoba"

, "Street (Company Address)"
: "Utca (Céges cím)"

, "Street 2 (Company Address)"
: "Utca 2 (Céges cím)"

, "City (Company Address)"
: "Város (Céges cím)"

, "Region (Company Address)"
: "Régió (Céges cím)"

, "Postal Code (Company Address)"
: "Irányítószám (Céges cím)"

, "Country (Company Address)"
: "Ország (Céges cím)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Utca (Privát cím)"

, "Street 2 (Private Address)"
: "Utca 2 (Privát cím)"

, "City (Private Address)"
: "Város (Privát cím)"

, "Region (Private Address)"
: "Régió (Privát cím)"

, "Postal Code (Private Address)"
: "Irányítószám (Privát cím)"

, "Country (Private Address)"
: "Ország (Privát cím)"

, "Company Communication"
: "Céges kapcsolatok"

, "Private Communication"
: "Privát kapcsolatok"

, "Web (private)"
: "Web (privát)"

, "Contacts"
: "Kapcsolatok"

, "Addressbooks"
: "Címjegyzékek"

, "User Account"
: "Felhasználói fiók"

, "Quick Search"
: ""

, "Type"
: "Típus"

, "Last Modified Time"
: "Utolsó módosítás ideje"

, "Last Modified By"
: "Utoljára módosította"

, "Creation Time"
: "Készítés ideje"

, "Created By"
: "Készítette"

, "List, Lists"
: [
  "Lista"
 ,"Listák"

]
, "Lists"
: "Listák"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Kapcsolatok importálása"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Címkék"

, "Full Name"
: "Teljes név"

, "Postalcode"
: "Irányítószám"

, "Street (private)"
: "Utca (privát)"

, "City (private)"
: "Város (privát)"

, "Region (private)"
: "Régió (privát)"

, "Postalcode (private)"
: "Irányítószám (privát)"

, "Country (private)"
: "Ország (privát)"

, "Email"
: "Email"

, "Car phone"
: "Autó telefon"

, "Pager"
: "Személyhívó"

, "Email (private)"
: "Email (privát)"

, "URL (private)"
: "URL (privát)"

, "Note"
: "Leírás"

, "Timezone"
: "Időzóna"

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Céges cím"

, "Private address"
: "Privát cím"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Összes kapcsolat"

, "Default Addressbook"
: "Alapértelmezett címjegyzék"

, "The default addressbook for new contacts"
: "Alapértelmezett címjegyzék az új kapcsolatoknak"

, "Default Favorite"
: "Alapértelmezett kedvenc"

, "The default favorite which is loaded on addressbook startup"
: "Alapértelmezett kedvenc ami a címjegyzék indításakor betöltődik"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Kapcsolat mezőinek duplikálási ellenőrzése"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Ezeket a mezőket ellenőrzi egy új kapcsolat felvételekor. Ha egy rekordt egyforma mező adatokkal megtalál, a duplikált kivételt eldobja."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Kapcsolat megszólítás elérhető"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Lehetséges kapcsolat megszólítás- Kérlek jegyezd meg, hogy azok további értékek ütközhetnek más Címjegyzék rendszerekkel exportáláskor vagy szinkronizáláskor."

, "Mr"
: "Úr"

, "Ms"
: "Asszony"

, "Parsing rules for addresses"
: "Címek felbontási szabályai"

, "Path to a XML file with address parsing rules."
: "Címek felbontási szabályait tartalmazó XML fájl elérése"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s személyes címjegyzéke"

, "Business Contact Data"
: "Üzleti Kapcsolati Adatok"

, "Organisation / Unit"
: "Szervezet / Egység"

, "Business Address"
: "Üzleti cím"

, "Telephone Work"
: "Üzleti telefonszám"

, "Telephone Cellphone"
: "Mobil telefonszám"

, "Telephone Car"
: "Autó telefonszám"

, "Telephone Fax"
: "Faxszám"

, "Telephone Page"
: "Személyhívó telefonszám"

, "URL"
: "URL"

, "Role"
: "Szerep"

, "Assistant"
: "Aszisztens"

, "Assistant Telephone"
: "Aszisztens telefonszáma"

, "Private Contact Data"
: "Privát Kapcsolati Adatok"

, "Email Home"
: "Otthoni email"

, "Telephone Home"
: "Otthoni telefonszám"

, "Telephone Cellphone Private"
: "Privát mobil telefonszám"

, "Telephone Fax Home"
: "Otthoni faxszám"

, "URL Home"
: "Otthoni URL"

, "Other Data"
: "Egyéb adatok"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Kapcsolat CSV importja Outlook címjegyzékből"

, "Contact CSV import from mac address book"
: "Kapcsolat CSV importja mac címjegyzékből"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Német Outlook 2007 CSV"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Kapcsolat VCARD importja"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Import lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kapcsolatokat importálta ###USERFULLNAME### ekkor: ###CURRENTDATE###  ###CURRENTTIME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Kapcsolatok importálása a Google címjegyzékből"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Belső kapcsolatok"

, "All contacts I have read grants for"
: "Összes kapcsolat, amihez olvasási engedélyem van"

, "My company"
: "Saját cégem"

, "All coworkers in my company"
: "Minden alkalmazott a saját cégemnél"

, "My contacts"
: "Kapcsolataim"

, "All contacts in my Addressbooks"
: "Minden kapcsolat a saját Címjegyzékemben"

, "Last modified by me"
: "Utoljára módosítottam"

, "All contacts that I have last modified"
: "Minden kapcsolat amit utoljára én módosítottam"

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "megosztott címjegyzékek kezelése"

, "Create new shared addressbook folders"
: "Új megosztott címjegyzék mappa készítése"

, "manage shared addressbook favorites"
: "kedvenc megosztott címjegyzék kezelése"

, "Create or update shared addressbook favorites"
: "Kedvenc megosztott címjegyzék készítése vagy frissítése"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Kapcsolat"

, "Addressbook"
: "Címjegyzék"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Lista"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
